==> saods9_6.2%2Bdfsg.orig.tar.gz: saods9/saotk/colorbar/default.h <==
// Copyright (C) 1999-2010
// Smithsonian Astrophysical Observatory, Cambridge, MA, USA
// For conditions of distribution and use, see copyright notice in "copyright"

#ifndef __default_h__
#define __default_h__

#include "sao.h"
#include "lut.h"

class GreyColorMap : public SAOColorMap {
public:
  GreyColorMap();
};

class RedColorMap : public SAOColorMap {
public:
  RedColorMap();
};

class GreenColorMap : public SAOColorMap {
public:
  GreenColorMap();
};

class BlueColorMap : public SAOColorMap {
public:
  BlueColorMap();
};

class AColorMap : public SAOColorMap {
public:
  AColorMap();
};

class BColorMap : public SAOColorMap {
public:
  BColorMap();
};

class BBColorMap : public SAOColorMap {
public:
  BBColorMap();
};

class HEColorMap : public SAOColorMap {
public:
  HEColorMap();
};

class I8ColorMap : public LUTColorMap {
public:
  I8ColorMap();
};

class AIPSColorMap : public LUTColorMap {
public:
  AIPSColorMap();
};

class HeatColorMap : public SAOColorMap {
public:
  HeatColorMap();
};

class CoolColorMap : public SAOColorMap {
public:
  CoolColorMap();
};

class RainbowColorMap : public SAOColorMap {
public:
  RainbowColorMap();
};

class StandardColorMap : public SAOColorMap {
public:
  StandardColorMap();
};

class StaircaseColorMap : public LUTColorMap {
public:
  StaircaseColorMap();
};

class ColorColorMap : public LUTColorMap {
public:
  ColorColorMap();
};

class SLSColorMap : public LUTColorMap {
public:
  SLSColorMap();
};

class HSVColorMap : public LUTColorMap {
public:
  HSVColorMap();
};

#endif

==> saods9_7.3~b3%2Bdfsg.orig.tar.gz: saods9/saotk/colorbar/default.h <==
// Copyright (C) 1999-2012
// Smithsonian Astrophysical Observatory, Cambridge, MA, USA
// For conditions of distribution and use, see copyright notice in "copyright"

#ifndef __default_h__
#define __default_h__

#include "sao.h"
#include "lut.h"

class Colorbar;

class GreyColorMap : public SAOColorMap {
public:
  GreyColorMap(Colorbar*);
};

class RedColorMap : public SAOColorMap {
public:
  RedColorMap(Colorbar*);
};

class GreenColorMap : public SAOColorMap {
public:
  GreenColorMap(Colorbar*);
};

class BlueColorMap : public SAOColorMap {
public:
  BlueColorMap(Colorbar*);
};

class AColorMap : public SAOColorMap {
public:
  AColorMap(Colorbar*);
};

class BColorMap : public SAOColorMap {
public:
  BColorMap(Colorbar*);
};

class BBColorMap : public SAOColorMap {
public:
  BBColorMap(Colorbar*);
};

class HEColorMap : public SAOColorMap {
public:
  HEColorMap(Colorbar*);
};

class I8ColorMap : public LUTColorMap {
public:
  I8ColorMap(Colorbar*);
};

class AIPSColorMap : public LUTColorMap {
public:
  AIPSColorMap(Colorbar*);
};

class HeatColorMap : public SAOColorMap {
public:
  HeatColorMap(Colorbar*);
};

class CoolColorMap : public SAOColorMap {
public:
  CoolColorMap(Colorbar*);
};

class RainbowColorMap : public SAOColorMap {
public:
  RainbowColorMap(Colorbar*);
};

class StandardColorMap : public SAOColorMap {
public:
  StandardColorMap(Colorbar*);
};

class StaircaseColorMap : public LUTColorMap {
public:
  StaircaseColorMap(Colorbar*);
};

class ColorColorMap : public LUTColorMap {
public:
  ColorColorMap(Colorbar*);
};

class SLSColorMap : public LUTColorMap {
public:
  SLSColorMap(Colorbar*);
};

class HSVColorMap : public LUTColorMap {
public:
  HSVColorMap(Colorbar*);
};

#endif
